# -*- coding: utf-8 -*-


# HTTP/2 Frame Type
_HTTP_TYPE = {
	0x00 : 'DATA',                                                                 # [RFC 7540, Section 6.1]
	0x01 : 'HEADERS',                                                              # [RFC 7540, Section 6.2]
	0x02 : 'PRIORITY',                                                             # [RFC 7540, Section 6.3]
	0x03 : 'RST_STREAM',                                                           # [RFC 7540, Section 6.4]
	0x04 : 'SETTINGS',                                                             # [RFC 7540, Section 6.5]
	0x05 : 'PUSH_PROMISE',                                                         # [RFC 7540, Section 6.6]
	0x06 : 'PING',                                                                 # [RFC 7540, Section 6.7]
	0x07 : 'GOAWAY',                                                               # [RFC 7540, Section 6.8]
	0x08 : 'WINDOW_UPDATE',                                                        # [RFC 7540, Section 6.9]
	0x09 : 'CONTINUATION',                                                         # [RFC 7540, Section 6.10]
	0x0A : 'ALTSVC',                                                               # [RFC 7838, Section 4]
	0x0B : 'Unassigned [0x0B]',
	0x0C : 'ORIGIN',                                                               # [RFC 8336]
	0x0D : 'Unassigned [0x0D]',
	0x0E : 'Unassigned [0x0E]',
	0x0F : 'Unassigned [0x0F]',
	0x10 : 'Unassigned [0x10]',
	0x11 : 'Unassigned [0x11]',
	0x12 : 'Unassigned [0x12]',
	0x13 : 'Unassigned [0x13]',
	0x14 : 'Unassigned [0x14]',
	0x15 : 'Unassigned [0x15]',
	0x16 : 'Unassigned [0x16]',
	0x17 : 'Unassigned [0x17]',
	0x18 : 'Unassigned [0x18]',
	0x19 : 'Unassigned [0x19]',
	0x1A : 'Unassigned [0x1A]',
	0x1B : 'Unassigned [0x1B]',
	0x1C : 'Unassigned [0x1C]',
	0x1D : 'Unassigned [0x1D]',
	0x1E : 'Unassigned [0x1E]',
	0x1F : 'Unassigned [0x1F]',
	0x20 : 'Unassigned [0x20]',
	0x21 : 'Unassigned [0x21]',
	0x22 : 'Unassigned [0x22]',
	0x23 : 'Unassigned [0x23]',
	0x24 : 'Unassigned [0x24]',
	0x25 : 'Unassigned [0x25]',
	0x26 : 'Unassigned [0x26]',
	0x27 : 'Unassigned [0x27]',
	0x28 : 'Unassigned [0x28]',
	0x29 : 'Unassigned [0x29]',
	0x2A : 'Unassigned [0x2A]',
	0x2B : 'Unassigned [0x2B]',
	0x2C : 'Unassigned [0x2C]',
	0x2D : 'Unassigned [0x2D]',
	0x2E : 'Unassigned [0x2E]',
	0x2F : 'Unassigned [0x2F]',
	0x30 : 'Unassigned [0x30]',
	0x31 : 'Unassigned [0x31]',
	0x32 : 'Unassigned [0x32]',
	0x33 : 'Unassigned [0x33]',
	0x34 : 'Unassigned [0x34]',
	0x35 : 'Unassigned [0x35]',
	0x36 : 'Unassigned [0x36]',
	0x37 : 'Unassigned [0x37]',
	0x38 : 'Unassigned [0x38]',
	0x39 : 'Unassigned [0x39]',
	0x3A : 'Unassigned [0x3A]',
	0x3B : 'Unassigned [0x3B]',
	0x3C : 'Unassigned [0x3C]',
	0x3D : 'Unassigned [0x3D]',
	0x3E : 'Unassigned [0x3E]',
	0x3F : 'Unassigned [0x3F]',
	0x40 : 'Unassigned [0x40]',
	0x41 : 'Unassigned [0x41]',
	0x42 : 'Unassigned [0x42]',
	0x43 : 'Unassigned [0x43]',
	0x44 : 'Unassigned [0x44]',
	0x45 : 'Unassigned [0x45]',
	0x46 : 'Unassigned [0x46]',
	0x47 : 'Unassigned [0x47]',
	0x48 : 'Unassigned [0x48]',
	0x49 : 'Unassigned [0x49]',
	0x4A : 'Unassigned [0x4A]',
	0x4B : 'Unassigned [0x4B]',
	0x4C : 'Unassigned [0x4C]',
	0x4D : 'Unassigned [0x4D]',
	0x4E : 'Unassigned [0x4E]',
	0x4F : 'Unassigned [0x4F]',
	0x50 : 'Unassigned [0x50]',
	0x51 : 'Unassigned [0x51]',
	0x52 : 'Unassigned [0x52]',
	0x53 : 'Unassigned [0x53]',
	0x54 : 'Unassigned [0x54]',
	0x55 : 'Unassigned [0x55]',
	0x56 : 'Unassigned [0x56]',
	0x57 : 'Unassigned [0x57]',
	0x58 : 'Unassigned [0x58]',
	0x59 : 'Unassigned [0x59]',
	0x5A : 'Unassigned [0x5A]',
	0x5B : 'Unassigned [0x5B]',
	0x5C : 'Unassigned [0x5C]',
	0x5D : 'Unassigned [0x5D]',
	0x5E : 'Unassigned [0x5E]',
	0x5F : 'Unassigned [0x5F]',
	0x60 : 'Unassigned [0x60]',
	0x61 : 'Unassigned [0x61]',
	0x62 : 'Unassigned [0x62]',
	0x63 : 'Unassigned [0x63]',
	0x64 : 'Unassigned [0x64]',
	0x65 : 'Unassigned [0x65]',
	0x66 : 'Unassigned [0x66]',
	0x67 : 'Unassigned [0x67]',
	0x68 : 'Unassigned [0x68]',
	0x69 : 'Unassigned [0x69]',
	0x6A : 'Unassigned [0x6A]',
	0x6B : 'Unassigned [0x6B]',
	0x6C : 'Unassigned [0x6C]',
	0x6D : 'Unassigned [0x6D]',
	0x6E : 'Unassigned [0x6E]',
	0x6F : 'Unassigned [0x6F]',
	0x70 : 'Unassigned [0x70]',
	0x71 : 'Unassigned [0x71]',
	0x72 : 'Unassigned [0x72]',
	0x73 : 'Unassigned [0x73]',
	0x74 : 'Unassigned [0x74]',
	0x75 : 'Unassigned [0x75]',
	0x76 : 'Unassigned [0x76]',
	0x77 : 'Unassigned [0x77]',
	0x78 : 'Unassigned [0x78]',
	0x79 : 'Unassigned [0x79]',
	0x7A : 'Unassigned [0x7A]',
	0x7B : 'Unassigned [0x7B]',
	0x7C : 'Unassigned [0x7C]',
	0x7D : 'Unassigned [0x7D]',
	0x7E : 'Unassigned [0x7E]',
	0x7F : 'Unassigned [0x7F]',
	0x80 : 'Unassigned [0x80]',
	0x81 : 'Unassigned [0x81]',
	0x82 : 'Unassigned [0x82]',
	0x83 : 'Unassigned [0x83]',
	0x84 : 'Unassigned [0x84]',
	0x85 : 'Unassigned [0x85]',
	0x86 : 'Unassigned [0x86]',
	0x87 : 'Unassigned [0x87]',
	0x88 : 'Unassigned [0x88]',
	0x89 : 'Unassigned [0x89]',
	0x8A : 'Unassigned [0x8A]',
	0x8B : 'Unassigned [0x8B]',
	0x8C : 'Unassigned [0x8C]',
	0x8D : 'Unassigned [0x8D]',
	0x8E : 'Unassigned [0x8E]',
	0x8F : 'Unassigned [0x8F]',
	0x90 : 'Unassigned [0x90]',
	0x91 : 'Unassigned [0x91]',
	0x92 : 'Unassigned [0x92]',
	0x93 : 'Unassigned [0x93]',
	0x94 : 'Unassigned [0x94]',
	0x95 : 'Unassigned [0x95]',
	0x96 : 'Unassigned [0x96]',
	0x97 : 'Unassigned [0x97]',
	0x98 : 'Unassigned [0x98]',
	0x99 : 'Unassigned [0x99]',
	0x9A : 'Unassigned [0x9A]',
	0x9B : 'Unassigned [0x9B]',
	0x9C : 'Unassigned [0x9C]',
	0x9D : 'Unassigned [0x9D]',
	0x9E : 'Unassigned [0x9E]',
	0x9F : 'Unassigned [0x9F]',
	0xA0 : 'Unassigned [0xA0]',
	0xA1 : 'Unassigned [0xA1]',
	0xA2 : 'Unassigned [0xA2]',
	0xA3 : 'Unassigned [0xA3]',
	0xA4 : 'Unassigned [0xA4]',
	0xA5 : 'Unassigned [0xA5]',
	0xA6 : 'Unassigned [0xA6]',
	0xA7 : 'Unassigned [0xA7]',
	0xA8 : 'Unassigned [0xA8]',
	0xA9 : 'Unassigned [0xA9]',
	0xAA : 'Unassigned [0xAA]',
	0xAB : 'Unassigned [0xAB]',
	0xAC : 'Unassigned [0xAC]',
	0xAD : 'Unassigned [0xAD]',
	0xAE : 'Unassigned [0xAE]',
	0xAF : 'Unassigned [0xAF]',
	0xB0 : 'Unassigned [0xB0]',
	0xB1 : 'Unassigned [0xB1]',
	0xB2 : 'Unassigned [0xB2]',
	0xB3 : 'Unassigned [0xB3]',
	0xB4 : 'Unassigned [0xB4]',
	0xB5 : 'Unassigned [0xB5]',
	0xB6 : 'Unassigned [0xB6]',
	0xB7 : 'Unassigned [0xB7]',
	0xB8 : 'Unassigned [0xB8]',
	0xB9 : 'Unassigned [0xB9]',
	0xBA : 'Unassigned [0xBA]',
	0xBB : 'Unassigned [0xBB]',
	0xBC : 'Unassigned [0xBC]',
	0xBD : 'Unassigned [0xBD]',
	0xBE : 'Unassigned [0xBE]',
	0xBF : 'Unassigned [0xBF]',
	0xC0 : 'Unassigned [0xC0]',
	0xC1 : 'Unassigned [0xC1]',
	0xC2 : 'Unassigned [0xC2]',
	0xC3 : 'Unassigned [0xC3]',
	0xC4 : 'Unassigned [0xC4]',
	0xC5 : 'Unassigned [0xC5]',
	0xC6 : 'Unassigned [0xC6]',
	0xC7 : 'Unassigned [0xC7]',
	0xC8 : 'Unassigned [0xC8]',
	0xC9 : 'Unassigned [0xC9]',
	0xCA : 'Unassigned [0xCA]',
	0xCB : 'Unassigned [0xCB]',
	0xCC : 'Unassigned [0xCC]',
	0xCD : 'Unassigned [0xCD]',
	0xCE : 'Unassigned [0xCE]',
	0xCF : 'Unassigned [0xCF]',
	0xD0 : 'Unassigned [0xD0]',
	0xD1 : 'Unassigned [0xD1]',
	0xD2 : 'Unassigned [0xD2]',
	0xD3 : 'Unassigned [0xD3]',
	0xD4 : 'Unassigned [0xD4]',
	0xD5 : 'Unassigned [0xD5]',
	0xD6 : 'Unassigned [0xD6]',
	0xD7 : 'Unassigned [0xD7]',
	0xD8 : 'Unassigned [0xD8]',
	0xD9 : 'Unassigned [0xD9]',
	0xDA : 'Unassigned [0xDA]',
	0xDB : 'Unassigned [0xDB]',
	0xDC : 'Unassigned [0xDC]',
	0xDD : 'Unassigned [0xDD]',
	0xDE : 'Unassigned [0xDE]',
	0xDF : 'Unassigned [0xDF]',
	0xE0 : 'Unassigned [0xE0]',
	0xE1 : 'Unassigned [0xE1]',
	0xE2 : 'Unassigned [0xE2]',
	0xE3 : 'Unassigned [0xE3]',
	0xE4 : 'Unassigned [0xE4]',
	0xE5 : 'Unassigned [0xE5]',
	0xE6 : 'Unassigned [0xE6]',
	0xE7 : 'Unassigned [0xE7]',
	0xE8 : 'Unassigned [0xE8]',
	0xE9 : 'Unassigned [0xE9]',
	0xEA : 'Unassigned [0xEA]',
	0xEB : 'Unassigned [0xEB]',
	0xEC : 'Unassigned [0xEC]',
	0xED : 'Unassigned [0xED]',
	0xEE : 'Unassigned [0xEE]',
	0xEF : 'Unassigned [0xEF]',
	0xF0 : 'Reserved for Experimental Use [0xF0]',                                 # [RFC 7540]
	0xF1 : 'Reserved for Experimental Use [0xF1]',                                 # [RFC 7540]
	0xF2 : 'Reserved for Experimental Use [0xF2]',                                 # [RFC 7540]
	0xF3 : 'Reserved for Experimental Use [0xF3]',                                 # [RFC 7540]
	0xF4 : 'Reserved for Experimental Use [0xF4]',                                 # [RFC 7540]
	0xF5 : 'Reserved for Experimental Use [0xF5]',                                 # [RFC 7540]
	0xF6 : 'Reserved for Experimental Use [0xF6]',                                 # [RFC 7540]
	0xF7 : 'Reserved for Experimental Use [0xF7]',                                 # [RFC 7540]
	0xF8 : 'Reserved for Experimental Use [0xF8]',                                 # [RFC 7540]
	0xF9 : 'Reserved for Experimental Use [0xF9]',                                 # [RFC 7540]
	0xFA : 'Reserved for Experimental Use [0xFA]',                                 # [RFC 7540]
	0xFB : 'Reserved for Experimental Use [0xFB]',                                 # [RFC 7540]
	0xFC : 'Reserved for Experimental Use [0xFC]',                                 # [RFC 7540]
	0xFD : 'Reserved for Experimental Use [0xFD]',                                 # [RFC 7540]
	0xFE : 'Reserved for Experimental Use [0xFE]',                                 # [RFC 7540]
	0xFF : 'Reserved for Experimental Use [0xFF]',                                 # [RFC 7540]
}
